@@ -5,16 +5,26 @@ import glob
 import lxml
 import lxml.etree
 import importlib.metadata
+
 __package__ = importlib.metadata.metadata("isaac-xml-validator").get("name")
 __version__ = importlib.metadata.version("isaac-xml-validator")
 
 parser = argparse.ArgumentParser()
-parser.add_argument("-v", '--version', action='version', version=str(__package__) +" "+str(__version__), help="Print version of package")
+parser.add_argument(
+    "-v",
+    "--version",
+    action="version",
+    version=str(__package__) + " " + str(__version__),
+    help="Print version of package",
+)
 parser.add_argument("-p", "--path", help="Path to folder")
-parser.add_argument("-r", "--recursive", help="Search thru folders recursively", type=bool)
+parser.add_argument(
+    "-r", "--recursive", help="Search through folders recursively", type=bool
+)
 parser.add_argument("-e", "--errors", help="Expected number of errors", type=int)
 args = parser.parse_args()
 
+
 class bcolors:
     HEADER = "\033[95m"
     OKBLUE = "\033[94m"
@@ -26,6 +36,7 @@ class bcolors:
     BOLD = "\033[1m"
     UNDERLINE = "\033[4m"
 
+
 SCRIPT_PATH = os.path.realpath(__file__)
 SCRIPT_DIRECTORY = os.path.dirname(SCRIPT_PATH)
 XSD_DIRECTORY = os.path.join(SCRIPT_DIRECTORY, "xsd")
@@ -47,30 +58,41 @@ if args.errors is not None:
 # Other global variables
 global error_count
 
-# Both of these files do not have a top-level tag, so they will always fail linting.
-# (The game's internal XML parser does not care about this.)
+
 file_ignore_list = [
+    # Ignore node module folders
+    "\\node_modules\\",
+    # Both of these files do not have a top-level tag, so they will always fail linting.
+    # (The game's internal XML parser does not care about this.)
     "fxlayers.xml",
     "seedmenu.xml",
 ]
 
+
 # ~~~~~~~~~~~~ Special conditions ~~~~~~~~~~~~
 
+
 def entity2_auto_increment_check(root, file_path):
     err_count = 0
     for child in list(root):
-        if child.tag == "entity" and child.get("id") is not None and child.get("variant") is None:
-            if (child.get("id") == "5" or child.get("id") == "1000"):
-                print_err(f"{file_path}:line {child.sourceline}: Element '{child.tag}': Variant attribute is missing. This is not allowed for IDs equal 5 or 1000!")
-                err_count +=1
+        if (
+            child.tag == "entity"
+            and child.get("id") is not None
+            and child.get("variant") is None
+        ):
+            if child.get("id") == "5" or child.get("id") == "1000":
+                print_err(
+                    f"{file_path}:line {child.sourceline}: Element '{child.tag}': Variant attribute is missing. This is not allowed for IDs equal 5 or 1000!"
+                )
+                err_count += 1
     return err_count
 
-special_conditions = {
-    "entities2.xml": [entity2_auto_increment_check]
-}
+
+special_conditions = {"entities2.xml": [entity2_auto_increment_check]}
 
 # ~~~~~~~~~~~~ Code ~~~~~~~~~~~~
 
+
 def clear_isaac_refs_recursive(node):
     for child in list(node):
         if child.get("type") is not None:
@@ -111,15 +133,15 @@ def main():
     total_error_count = 0
 
     files = glob.glob(root_folder + "/**.xml", recursive=recursive)
+    # remove files and folders to ignore
+    for ignoreFile in file_ignore_list:
+        files = [f for f in files if ignoreFile not in f]
+
     printf(f"Found {len(files)} files in path: {root_folder}/**.xml")
 
     for file_path in files:
         error_count = 0
-
         file_name = os.path.basename(file_path)
-        if file_name in file_ignore_list:
-            print_warn(f"Skipping ignored XML file: {file_path}")
-            continue
 
         printf(f"Checking XML file: {file_path}")
 
@@ -165,6 +187,7 @@ def main():
     else:
         print_ok("No errors found")
 
+
 def evaluate_special_conditions(xml_file_path: str):
     """Checks file specific conditions that could not be evaluated with XSD schemas"""
     try:
@@ -206,6 +229,7 @@ def parse_isaac_xml_file(xml_file_path: str, xsd_file_path: str):
         print_err(err)
         return xml_schema.error_log
 
+
 def read_github_env_vars():
     global root_folder, expected_error_count, recursive
     printf("Evaluate settings:")
